@@ -7,6 +7,7 @@ import (
 	"regexp"
 	"strconv"
 	"strings"
+	"sync/atomic"
 	"unicode/utf8"
 
 	log "github.com/sirupsen/logrus"
@@ -80,6 +81,8 @@ type UnixScreen struct {
 
 	events chan Event
 
+	shutdownRequested atomic.Bool
+
 	ttyIn            *os.File
 	oldTerminalState *term.State //nolint Not used on Windows
 	oldTtyInMode     uint32      //nolint Windows only
@@ -173,18 +176,23 @@ func (screen *UnixScreen) Close() {
 	// Tell the pager to exit unless it hasn't already
 	screen.events <- EventExit{}
 
-	// Tell our main loop to exit. It may still be stuck in a read() call after
-	// this, but even if it posts nore events the pager has already exited and
-	// nobody will care.
-	screen.ttyIn.Close()
+	// Tell our main loop to exit. Previously we used to close the screen.ttyIn
+	// file descriptor here, but:
+	// * That didn't interrupt the blocking read() in the main loop
+	// * It may or may not have caused shutdown issues on Windows
+	//
+	// Setting this flag doesn't interrupt the blocking read() either, but it
+	// is should at least be less likely to cause shutdown issues on Windows.
+	//
+	// Ref:
+	// * https://github.com/walles/moar/issues/217
+	// * https://github.com/walles/moar/issues/221
+	screen.shutdownRequested.Store(true)
 
 	screen.hideCursor(false)
 	screen.enableMouseTracking(false)
 	screen.setAlternateScreenMode(false)
 
-	// This will make the main loop exit
-	screen.ttyIn.Close()
-
 	err := screen.restoreTtyInTtyOut()
 	if err != nil {
 		// Debug logging because this is expected to fail in some cases:
@@ -353,6 +361,10 @@ func (screen *UnixScreen) ShowCursorAt(column int, row int) {
 }
 
 func (screen *UnixScreen) mainLoop() {
+	defer func() {
+		log.Debug("Twin screen main loop done")
+	}()
+
 	// "1400" comes from me trying fling scroll operations on my MacBook
 	// trackpad and looking at the high watermark (logged below).
 	//
@@ -371,8 +383,13 @@ func (screen *UnixScreen) mainLoop() {
 			// * https://github.com/walles/moar/issues/150
 			log.Debug("ttyin read error, twin giving up: ", err)
 
-			var event Event = EventExit{}
-			screen.events <- event
+			screen.events <- EventExit{}
+			return
+		}
+		if screen.shutdownRequested.Load() {
+			log.Debug("Shutdown requested, twin giving up")
+
+			screen.events <- EventExit{}
 			return
 		}
 
